@@ -305,6 +305,27 @@ def load(buf, pedantic=False):
     """
     return _Load()(buf, pedantic)
 
+def unrepr(buf, pedantic=False):
+    """
+    Return an object from its canonical string representation, buf.
+
+    This is a specialized version of load() operating on the canonical
+    representation of a single value instead than on a sequence of
+    assignment statements. This should never fail on any possible
+    values of data where data only includes supported types (see
+    above):
+
+    >>> assert(data == unrepr(repr(data)))
+
+    The pedantic argument has the same meaning than for load(). On
+    error, it can raise a SyntaxError, TypeError or ValueError
+    exception.
+    """
+
+    # Let's reuse the same interface than for load: it is somewhat
+    # suboptimal, but cleaner.
+    return _Load()('data = %s' % buf, pedantic)['data']
+
 def dump(data, comments={}, pedantic=True, **kw):
     """
     Dump configuration from dictionary, returning a string.
@@ -337,3 +358,4 @@ def dump(data, comments={}, pedantic=True, **kw):
     rules apply to them.
     """
     return _Dump()(data, headers=comments, pedantic=pedantic, **kw)
+
